@@ -11,7 +11,8 @@ use gitql_core::environment::Environment;
 use gitql_core::object::GitQLObject;
 use gitql_core::object::Group;
 use gitql_core::object::Row;
-use gitql_core::value::Value;
+use gitql_core::values::base::Value;
+use gitql_core::values::text::TextValue;
 
 use crate::data_provider::DataProvider;
 use crate::engine_distinct::apply_distinct_operator;
@@ -32,7 +33,7 @@ const FIXED_LOGICAL_PLAN: [&str; 8] = [
 ];
 
 pub enum EvaluationResult {
-    Do(Value),
+    Do(Box<dyn Value>),
     SelectedGroups(GitQLObject),
     SelectedInfo,
     SetGlobalVariable,
@@ -129,9 +130,14 @@ fn evaluate_select_query(
     }
 
     // Remove Hidden Selection from the rows after executing the query plan
+    remove_hidden_selected_from_groups(
+        &mut gitql_object.titles,
+        &mut gitql_object.groups,
+        &hidden_selections,
+    );
+
     let number_of_groups = gitql_object.groups.len();
-    let group: &mut Group = &mut gitql_object.groups[0];
-    remove_hidden_selected(&mut gitql_object.titles, group, &hidden_selections);
+    let main_group: &mut Group = &mut gitql_object.groups[0];
 
     // If there are many groups that mean group by is executed before.
     // must merge each group into only one element
@@ -141,15 +147,16 @@ fn evaluate_select_query(
                 group.rows.drain(1..);
             }
         }
+        gitql_object.flat();
     }
     // If it a single group but it select only aggregations function,
     // should return only first element in the group
     else if number_of_groups == 1
         && !query.has_group_by_statement
         && query.has_aggregation_function
-        && group.len() > 1
+        && main_group.len() > 1
     {
-        group.rows.drain(1..);
+        main_group.rows.drain(1..);
     }
 
     // Into statement must be executed last after flatted and remove hidden selections
@@ -198,8 +205,12 @@ fn evaluate_describe_query(
         let value = env.schema.tables_fields_types.get(field).unwrap();
         rows.push(Row {
             values: vec![
-                Value::Text(field.to_owned().to_owned()),
-                Value::Text(value.to_string()),
+                Box::new(TextValue {
+                    value: field.to_owned().to_owned(),
+                }),
+                Box::new(TextValue {
+                    value: value.literal(),
+                }),
             ],
         })
     }
@@ -216,7 +227,9 @@ fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult,
     for table in env.schema.tables_fields_names.keys() {
         gitql_object.groups.push(Group {
             rows: vec![Row {
-                values: vec![Value::Text(table.to_owned().to_owned())],
+                values: vec![Box::new(TextValue {
+                    value: table.to_owned().to_owned(),
+                })],
             }],
         })
     }
@@ -224,19 +237,24 @@ fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult,
     Ok(EvaluationResult::SelectedGroups(gitql_object))
 }
 
-fn remove_hidden_selected(
+fn remove_hidden_selected_from_groups(
     titles: &mut Vec<String>,
-    group: &mut Group,
+    groups: &mut [Group],
     hidden_selections: &[String],
 ) {
     let titles_count = titles.len();
+    let mut index_list: Vec<usize> = vec![];
     for i in (0..titles_count).rev() {
         if hidden_selections.contains(&titles[i]) {
             titles.remove(i);
+            index_list.push(i);
+        }
+    }
+
+    for group in groups.iter_mut() {
+        for index_to_delete in index_list.iter() {
             for row in group.rows.iter_mut() {
-                if row.values.len() > i {
-                    row.values.remove(i);
-                }
+                row.values.remove(*index_to_delete);
             }
         }
     }
