@@ -23,6 +23,8 @@ pub enum TokenKind {
     Show,
     RegExp,
 
+    Benchmark,
+
     Join,
     Left,
     Right,
@@ -56,8 +58,12 @@ pub enum TokenKind {
     BangEqual,
     NullSafeEqual,
 
+    /// @>
     AtRightArrow,
 
+    /// <@
+    ArrowRightAt,
+
     As,
 
     With,
@@ -162,7 +168,7 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
                 let token = Token {
                     location,
                     kind: TokenKind::AtRightArrow,
-                    literal: "@".to_owned(),
+                    literal: "@>".to_owned(),
                 };
 
                 tokens.push(token);
@@ -569,6 +575,10 @@ pub fn tokenize(script: String) -> Result<Vec<Token>, Box<Diagnostic>> {
                 position += 1;
                 kind = TokenKind::BangEqual;
                 "<>"
+            } else if position < len && characters[position] == '@' {
+                position += 1;
+                kind = TokenKind::ArrowRightAt;
+                "<@"
             } else {
                 "<"
             };
@@ -1159,6 +1169,8 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "show" => TokenKind::Show,
         "regexp" => TokenKind::RegExp,
 
+        "benchmark" => TokenKind::Benchmark,
+
         // Select into
         "into" => TokenKind::Into,
         "outfile" => TokenKind::Outfile,
