@@ -9,7 +9,10 @@ use gitql_cli::arguments::Command;
 use gitql_cli::arguments::OutputFormat;
 use gitql_cli::diagnostic_reporter;
 use gitql_cli::diagnostic_reporter::DiagnosticReporter;
-use gitql_cli::render;
+use gitql_cli::printer::base::OutputPrinter;
+use gitql_cli::printer::csv_printer::CSVPrinter;
+use gitql_cli::printer::json_printer::JSONPrinter;
+use gitql_cli::printer::table_printer::TablePrinter;
 use gitql_core::environment::Environment;
 use gitql_core::schema::Schema;
 use gitql_engine::data_provider::DataProvider;
@@ -20,9 +23,11 @@ use gitql_parser::parser;
 use gitql_parser::tokenizer;
 use gitql_std::aggregation::aggregation_function_signatures;
 use gitql_std::aggregation::aggregation_functions;
+use lineeditor::LineEditorResult;
 
 mod git_data_provider;
 mod git_functions;
+mod git_line_editor;
 mod git_schema;
 
 fn main() {
@@ -62,8 +67,8 @@ fn main() {
             let aggregation_functions = aggregation_functions();
 
             let mut env = Environment::new(schema);
-            env.with_standard_functions(std_signatures, std_functions);
-            env.with_aggregation_functions(aggregation_signatures, aggregation_functions);
+            env.with_standard_functions(&std_signatures, std_functions);
+            env.with_aggregation_functions(&aggregation_signatures, aggregation_functions);
 
             execute_gitql_query(query, &arguments, &repos, &mut env, &mut reporter);
         }
@@ -102,13 +107,42 @@ fn launch_gitql_repl(arguments: Arguments) {
     let aggregation_functions = aggregation_functions();
 
     let mut global_env = Environment::new(schema);
-    global_env.with_standard_functions(std_signatures, std_functions);
-    global_env.with_aggregation_functions(aggregation_signatures, aggregation_functions);
+    global_env.with_standard_functions(&std_signatures, std_functions);
+    global_env.with_aggregation_functions(&aggregation_signatures, aggregation_functions);
 
     let git_repositories = git_repos_result.ok().unwrap();
 
-    let mut input = String::new();
+    // Launch the right line editor if the flag is enabled
+    // Later this line editor will be the default editor
+    if arguments.enable_line_editor {
+        let mut line_editor = git_line_editor::create_new_line_editor();
+        loop {
+            if let Ok(LineEditorResult::Success(input)) = line_editor.read_line() {
+                println!();
 
+                if input.is_empty() || input == "\n" {
+                    continue;
+                }
+
+                if input == "exit" {
+                    break;
+                }
+
+                execute_gitql_query(
+                    input.to_owned(),
+                    &arguments,
+                    &git_repositories,
+                    &mut global_env,
+                    &mut reporter,
+                );
+
+                global_env.clear_session();
+            }
+        }
+        return;
+    }
+
+    let mut input = String::new();
     loop {
         // Render Prompt only if input is received from terminal
         if atty::is(Stream::Stdin) {
@@ -195,32 +229,26 @@ fn execute_gitql_query(
     }
 
     // Render the result only if they are selected groups not any other statement
+    let mut rows_count = 0;
     let engine_result = evaluation_result.ok().unwrap();
     if let SelectedGroups(mut groups) = engine_result {
-        match arguments.output_format {
+        rows_count += groups.len();
+        let printer: Box<dyn OutputPrinter> = match arguments.output_format {
             OutputFormat::Render => {
-                render::render_objects(&mut groups, arguments.pagination, arguments.page_size);
+                Box::new(TablePrinter::new(arguments.pagination, arguments.page_size))
             }
-            OutputFormat::JSON => {
-                if let Ok(json) = groups.as_json() {
-                    println!("{}", json);
-                }
-            }
-            OutputFormat::CSV => {
-                if let Ok(csv) = groups.as_csv() {
-                    println!("{}", csv);
-                }
-            }
-        }
+            OutputFormat::JSON => Box::new(JSONPrinter {}),
+            OutputFormat::CSV => Box::new(CSVPrinter {}),
+        };
+        printer.print(&mut groups);
     }
 
     if arguments.analysis {
-        println!("\n");
-        println!("Analysis:");
-        println!("Frontend : {:?}", front_duration);
-        println!("Engine   : {:?}", engine_duration);
-        println!("Total    : {:?}", (front_duration + engine_duration));
-        println!("\n");
+        let total_time = front_duration + engine_duration;
+        println!(
+            "{} row in set (total: {:?}, front: {:?}, engine: {:?})",
+            rows_count, total_time, front_duration, engine_duration
+        );
     }
 }
 
